@@ -646,16 +646,18 @@ def mg_run(args, config, console):
         repo_path = absolute_repo_path(args, repo.name)
 
         try:
-            status = subprocess.run(args.parameters, cwd=repo_path, check=False)
+            status = subprocess.run(args.parameters, cwd=repo_path, check=True)
+
         except FileNotFoundError:
             err_msg = f'"[BLUE:{args.parameters[0]}]" - Command not found'
             if args.error_continue:
                 colour.write(f'[RED:WARNING]: {err_msg}')
             else:
                 colour.error(f'[RED:ERROR]: {err_msg}')
-        else:
-            if status.returncode and not args.error_continue:
-                sys.exit(status)
+
+        except subprocess.CalledProcessError as exc:                
+            if not args.error_continue:
+                sys.exit(exc.returncode)
 
 ################################################################################
 
